#
# spec file for package tinyca2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define	libdir		%{_datadir}/TinyCA2/lib
%define	templatesdir	%{_datadir}/TinyCA2/templates
%define	localedir	%{_datadir}/locale/
Name:           tinyca2
Version:        0.7.5
Release:        bp155.2.9
Summary:        A Graphical Tool for Managing a Certification Authority
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Security
URL:            http://tinyca.sm-zone.net/
Source0:        %{name}-%{version}.tar.bz2
Patch0:         0001-fix-combobox-strings-for-extended-key-usage.diff
Patch1:         0002-add-support-for-Microsoft-extendedKeyUsage-attributes.diff
Patch2:         0001-fix-paranthesis-use.diff
Patch3:         0002-fix-deprecation-warning.diff
Patch4:         0003-fix-compatibility-with-openssl-1.0.1.diff
Patch5:         0004-fix-perl-deprecation-defined.diff
BuildRequires:  update-desktop-files
Requires:       perl
Requires:       perl-Gtk2
Requires:       perl-MIME-Base64
Provides:       tinyca:%{_bindir}/tinyca
BuildArch:      noarch

%description
TinyCA is a graphical tool to manage a small Certification Authority
(CA) using openssl.

TinyCA supports - creation and revocation of x509 - S/MIME
   certificates.

- PKCS#10 requests.

- exporting certificates as PEM, DER, TXT, and PKCS#12.

- server certificates for use in web servers, email servers, IPsec,
   and more.

- client certificates for use in web browsers, email clients, IPsec,
and more.

%prep
%autosetup -p1

%build
# Configure pristine source
sed -i -e 's:./lib:%{libdir}:g;s:./templates:%{templatesdir}:g' tinyca2
sed -i -e '/bindtextdomain/d' tinyca2
make %{?_smp_mflags} -C po

%install
install -d -m 755 %{buildroot}%{_bindir}
install -d -m 755 %{buildroot}%{libdir}
install -d -m 755 %{buildroot}%{libdir}/GUI
install -d -m 755 %{buildroot}%{templatesdir}
install -d -m 755 %{buildroot}%{_datadir}/applications
install -m 644 lib/*.pm %{buildroot}%{libdir}
install -m 644 lib/GUI/*.pm %{buildroot}%{libdir}/GUI
install -m 644 templates/openssl.cnf %{buildroot}%{templatesdir}
install -m 755 tinyca2 %{buildroot}%{_bindir}
pushd locale
for i in *; do
	install -d -m 755 %{buildroot}%{localedir}/$i/LC_MESSAGES
	install -m 644 $i/LC_MESSAGES/tinyca2.mo %{buildroot}%{localedir}/$i/LC_MESSAGES/
done
popd
cat > %{buildroot}%{_datadir}/applications/tinyca2.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Type=Application
GenericName=Tool to manage a Certification Authority
Name=TinyCA2
Exec=tinyca2
EOF
%suse_update_desktop_file tinyca2 Security Utility
%find_lang %{name}

%files -f %{name}.lang
%doc CHANGES
%dir %{_datadir}/TinyCA2
%dir %{_datadir}/TinyCA2/lib
%dir %{_datadir}/TinyCA2/templates
%{_datadir}/TinyCA2/lib/*
%{_datadir}/TinyCA2/templates/*
%{_bindir}/tinyca2
%{_datadir}/applications/*

%changelog
* Fri Oct  5 2018 lnussel@suse.de
- run spec-cleaner
* Fri Oct  5 2018 gatherer@rursee.net
- fix perl decprecation defined on hash/array types (boo#1072060,
  0004-fix-perl-deprecation-defined.diff)
* Fri Nov 29 2013 lnussel@suse.de
- fix tinyca not starting up (bnc#848907) and some deprecation warnings
  0001-fix-paranthesis-use.diff
  0002-fix-deprecation-warning.diff
  0003-fix-compatibility-with-openssl-1.0.1.diff
* Tue Jul  5 2011 lnussel@suse.de
- move locales to system dir to avoid not owned directories
* Sat Jan 15 2011 lnussel@suse.de
- add support for Microsoft extendedKeyUsage attributes
- fix combobox strings for extended key usage
* Sun Mar 16 2008 crrodriguez@suse.de
- fix file-not-in-lang rpmlint warnings
* Tue Jul  4 2006 lnussel@suse.de
- new version 0.7.4
  * fix some crashes
  * fix problems with umlauts
  * fix crl handling with different openssl versions
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Aug 30 2005 mmarek@suse.cz
- Use the OO interface of Locale::gettext, which converts strings
  into Perl's internal encoding, so that Gtk widgets are displayed
  correctly (#95903).
* Mon Jul 11 2005 lnussel@suse.de
- update to tinyca2 version 0.7.0
* Wed Mar 16 2005 lnussel@suse.de
- Use desktop file from package (fixes #72277)
* Mon Nov 29 2004 lnussel@suse.de
- new version 0.6.6
* Fri Sep 24 2004 mskibbe@suse.de
- change desktop files
* Thu Aug  5 2004 lnussel@suse.de
- new version 0.6.5
* Mon Jul 19 2004 lnussel@suse.de
- new version 0.6.4
* Fri Feb  6 2004 hmacht@suse.de
- building as non-root (#norootforbuild)
* Thu Oct  9 2003 lnussel@suse.de
- new version 0.5.4
* Sun Sep  7 2003 adrian@suse.de
- add Categories
* Tue Sep  2 2003 lnussel@suse.de
- new version 0.5.2 allows renewal of certificates
* Wed Aug 27 2003 lnussel@suse.de
- new version 0.5.1
* Mon Aug 18 2003 ro@suse.de
- added update-desktop-files to neededforbuild
* Mon Aug 18 2003 lnussel@suse.de
- new version 0.5.0: uses perl-Gtk instead of perl-Tk
- add desktop file
* Thu Jul 24 2003 lnussel@suse.de
- initial package for version 0.4.9
